# -*- coding: utf-8 -*-
"""
Created on Sat Jul 21 23:15:59 2018

@author: ASIS
"""

from distutils.core import setup

setup(name='mymath_arun_v1',
      version='0.1',
      description='A silly math package',
      author='Mike Driscoll',
      author_email='mike@mymath.org',
      url='http://www.mymath.org/',
      packages=['mymath_arun_v1', 'mymath_arun_v1.adv'],
     )